@@ -1,5 +1,5 @@
 ﻿/*
- *  This file is part of Poedit (http://poedit.net)
+ *  This file is part of Poedit (https://poedit.net)
  *
  *  Copyright (C) 1999-2016 Vaclav Slavik
  *
@@ -1047,6 +1047,18 @@ void PoeditApp::OnAbout(wxCommandEvent&)
     // TRANSLATORS: This is version information in about dialog, "%s" will be
     //              version number when used
     _("Version %s");
+
+    // TRANSLATORS: OS X item in app menu
+    _("Services");
+    // TRANSLATORS: OS X item in app menu, %s is replaced with "Poedit"
+    _("Hide %s");
+    // TRANSLATORS: OS X item in app menu
+    _("Hide Others");
+    // TRANSLATORS: OS X item in app menu
+    _("Show All");
+    // TRANSLATORS: OS X item in app menu, %s is replaced with "Poedit"
+    _("Quit %s");
+    _("Preferences...");
 #endif
 
     wxAboutDialogInfo about;
@@ -1058,7 +1070,7 @@ void PoeditApp::OnAbout(wxCommandEvent&)
 #endif
     about.SetCopyright(L"Copyright \u00a9 1999-2016 Václav Slavík");
 #ifdef __WXGTK__ // other ports would show non-native about dlg
-    about.SetWebSite("http://poedit.net");
+    about.SetWebSite("https://poedit.net");
 #endif
 
     wxAboutBox(about);
@@ -1082,14 +1094,12 @@ void PoeditApp::OnQuit(wxCommandEvent&)
         if (w.sheet && w.visible && w.preventsApplicationTerminationWhenModal)
             return;
     }
-#endif
 
     // The Close() calls below may not terminate immediately, they may ask for
     // confirmation window-modally on OS X. So change the behavior to terminate
     // the app when the last window is closed now, instead of calling
     // ExitMainLoop(). This will terminate the app automagically when all the
     // windows are closed.
-
     bool delayed = false;
     for ( auto& i : wxTopLevelWindows )
     {
@@ -1101,6 +1111,18 @@ void PoeditApp::OnQuit(wxCommandEvent&)
         SetExitOnFrameDelete(true);
     else
         ExitMainLoop();
+
+#else // !__WXOSX__
+
+    for ( auto& i : wxTopLevelWindows )
+    {
+        if (!i->Close())
+            return;
+    }
+
+    ExitMainLoop();
+
+#endif
 }
 
 
@@ -1124,7 +1146,7 @@ void PoeditApp::OnHelp(wxCommandEvent&)
 
 void PoeditApp::OnGettextManual(wxCommandEvent&)
 {
-    wxLaunchDefaultBrowser("http://www.gnu.org/software/gettext/manual/");
+    wxLaunchDefaultBrowser("http://www.gnu.org/software/gettext/manual/html_node/");
 }
 
 
@@ -1132,7 +1154,7 @@ void PoeditApp::OpenPoeditWeb(const wxString& path)
 {
     wxLaunchDefaultBrowser
     (
-        wxString::Format("http://poedit.net%s?fromVersion=%s",
+        wxString::Format("https://poedit.net%s?fromVersion=%s",
                          path,
                          GetAppVersion())
     );
