@@ -1,5 +1,5 @@
 ﻿/*
- *  This file is part of Poedit (http://poedit.net)
+ *  This file is part of Poedit (https://poedit.net)
  *
  *  Copyright (C) 1999-2016 Vaclav Slavik
  *  Copyright (C) 2005 Olivier Sannier
@@ -29,6 +29,8 @@
 #include "hidpi.h"
 #include "language.h"
 #include "cat_sorting.h"
+#include "unicode_helpers.h"
+#include "utility.h"
 
 #include <wx/wx.h>
 #include <wx/imaglist.h>
@@ -37,6 +39,11 @@
 #include <wx/image.h>
 #include <wx/wupdlock.h>
 
+#ifdef __WXMSW__
+#include <wx/msw/uxtheme.h>
+#include <vssym32.h>
+#endif
+
 #include <algorithm>
 
 
@@ -146,6 +153,13 @@ PoeditListCtrl::PoeditListCtrl(wxWindow *parent,
                const wxString &name)
      : wxListView(parent, id, pos, size, style | wxLC_VIRTUAL, validator, name)
 {
+#ifdef __WXMSW__
+    if (wxApp::GetComCtl32Version() >= 600)
+    {
+        ::SendMessage(GetHwnd(), LVM_SETEXTENDEDLISTVIEWSTYLE, LVS_EX_DOUBLEBUFFER, LVS_EX_DOUBLEBUFFER);
+    }
+#endif
+
     m_displayIDs = dispIDs;
 
     m_isRTL = false;
@@ -175,9 +189,7 @@ PoeditListCtrl::PoeditListCtrl(wxWindow *parent,
 #ifdef __WXMSW__
     // On Windows 7, shaded list items make it impossible to see the selection,
     // so use different color for it (see bug #336).
-    int verMaj, verMin;
-    wxGetOsVersion(&verMaj, &verMin);
-    if ( verMaj > 6 || (verMaj == 6 && verMin >= 1) )
+    if (IsWindows7OrGreater())
     {
         shaded.Set(int(0.99 * shaded.Red()),
                    int(0.99 * shaded.Green()),
@@ -232,6 +244,38 @@ PoeditListCtrl::PoeditListCtrl(wxWindow *parent,
         m_attrId.SetTextColour(wxColour("#A1A1A1"));
 
     SetCustomFont(wxNullFont);
+
+#ifdef __WXMSW__
+    // Setup custom header font & color on Windows 10, where the default look is a bit odd
+    if (IsWindows10OrGreater())
+    {
+        wxItemAttr headerAttr;
+
+        // Use the same text color as Explorer's headers use
+        const wxUxThemeEngine* theme = wxUxThemeEngine::GetIfActive();
+        if (theme)
+        {
+            wxUxThemeHandle hTheme(this, L"ItemsView::Header");
+            COLORREF clr;
+            HRESULT hr = theme->GetThemeColor(hTheme, HP_HEADERITEM, 0, TMT_TEXTCOLOR, &clr);
+            if (SUCCEEDED(hr))
+                headerAttr.SetTextColour(wxRGBToColour(clr));
+        }
+
+        // In HiDPI modes, standard header has smaller height than Explorer's and it isn't
+        // separated from the content well. wxListCtrl doesn't allow for customized header
+        // height (unlike wxDVC), so as a temporary workaround, at least make the text
+        // slightly larger to compensate. 
+        if (HiDPIScalingFactor() > 1.0)
+        {
+            auto headerFont = visual.font;
+            headerFont.SetPointSize(headerFont.GetPointSize() + 1);
+            headerAttr.SetFont(headerFont);
+        }
+
+        SetHeaderAttr(headerAttr);
+    }
+#endif // __WXMSW__
 }
 
 PoeditListCtrl::~PoeditListCtrl()
@@ -468,19 +512,23 @@ wxString PoeditListCtrl::OnGetItemText(long item, long column) const
         else
             orig = d->GetString();
 
+        orig = orig.substr(0, GetMaxColChars());
+
         // Add RTL Unicode mark to render bidi texts correctly
         if (m_appIsRTL)
-            return L"\u202a" + orig.substr(0,GetMaxColChars());
+            return bidi::LRE + orig;
         else
-            return orig.substr(0,GetMaxColChars());
+            return orig;
     }
     else if (column == m_colTrans)
     {
+        auto trans = d->GetTranslation().substr(0, GetMaxColChars());
+
         // Add RTL Unicode mark to render bidi texts correctly
         if (m_isRTL && !m_appIsRTL)
-            return L"\u202b" + d->GetTranslation();
+            return bidi::RLE + trans;
         else
-            return d->GetTranslation();
+            return trans;
     }
     else if (column == m_colId)
     {
