@@ -1,5 +1,5 @@
 /*
- *  This file is part of Poedit (http://poedit.net)
+ *  This file is part of Poedit (https://poedit.net)
  *
  *  Copyright (C) 2001-2016 Vaclav Slavik
  *
@@ -592,6 +592,8 @@ bool FindFrame::DoReplaceInItem(CatalogItemPtr item)
 
 void FindFrame::OnReplace(wxCommandEvent&)
 {
+    if (!m_lastItem)
+        return;
     DoReplaceInItem(m_lastItem);
     m_listCtrl->Refresh();
 }
