@@ -1,5 +1,5 @@
 ﻿/*
- *  This file is part of Poedit (http://poedit.net)
+ *  This file is part of Poedit (https://poedit.net)
  *
  *  Copyright (C) 1999-2016 Vaclav Slavik
  *
@@ -50,17 +50,49 @@
 
 #include "spellchecking.h"
 #include "str_helpers.h"
+#include "unicode_helpers.h"
 
 
 namespace
 {
 
 #ifdef __WXOSX__
+
 inline NSTextView *TextView(const wxTextCtrl *ctrl)
 {
     NSScrollView *scroll = (NSScrollView*)ctrl->GetHandle();
     return [scroll documentView];
 }
+
+class DisableAutomaticSubstitutions
+{
+public:
+    DisableAutomaticSubstitutions(wxTextCtrl *ctrl) : m_view(TextView(ctrl))
+    {
+        m_dash = m_view.automaticDashSubstitutionEnabled;
+        m_quote = m_view.automaticQuoteSubstitutionEnabled;
+        m_text = m_view.automaticTextReplacementEnabled;
+        m_spelling = m_view.automaticSpellingCorrectionEnabled;
+
+        m_view.automaticDashSubstitutionEnabled = NO;
+        m_view.automaticQuoteSubstitutionEnabled = NO;
+        m_view.automaticTextReplacementEnabled = NO;
+        m_view.automaticSpellingCorrectionEnabled = NO;
+    }
+
+    DisableAutomaticSubstitutions()
+    {
+        m_view.automaticDashSubstitutionEnabled = m_dash;
+        m_view.automaticQuoteSubstitutionEnabled = m_quote;
+        m_view.automaticTextReplacementEnabled = m_text;
+        m_view.automaticSpellingCorrectionEnabled = m_spelling;
+    }
+
+private:
+    NSTextView *m_view;
+    BOOL m_quote, m_dash, m_text, m_spelling;
+};
+
 #endif // __WXOSX__
 
 
@@ -470,37 +502,47 @@ AnyTranslatableTextCtrl::AnyTranslatableTextCtrl(wxWindow *parent, wxWindowID wi
         HighlightText();
     });
 
-#ifdef __WXMSW__
-    m_isRTL = false;
-#endif
+    m_language = Language::English();
 }
 
 AnyTranslatableTextCtrl::~AnyTranslatableTextCtrl()
 {
 }
 
-void AnyTranslatableTextCtrl::SetLanguageRTL(bool isRTL)
+void AnyTranslatableTextCtrl::SetLanguage(const Language& lang)
 {
+    m_language = lang;
+
 #ifdef __WXOSX__
     NSTextView *text = TextView(this);
-    [text setBaseWritingDirection:isRTL ? NSWritingDirectionRightToLeft : NSWritingDirectionLeftToRight];
+    [text setBaseWritingDirection:lang.IsRTL() ? NSWritingDirectionRightToLeft : NSWritingDirectionLeftToRight];
 #endif
 #ifdef __WXMSW__
-    m_isRTL = isRTL;
-
     BIDIOPTIONS bidi;
     ::ZeroMemory(&bidi, sizeof(bidi));
     bidi.cbSize = sizeof(bidi);
     bidi.wMask = BOM_UNICODEBIDI;
-    bidi.wEffects = isRTL ? BOE_UNICODEBIDI : 0;
+    bidi.wEffects = lang.IsRTL() ? BOE_UNICODEBIDI : 0;
     ::SendMessage((HWND)GetHWND(), EM_SETBIDIOPTIONS, 0, (LPARAM) &bidi);
 
-    ::SendMessage((HWND)GetHWND(), EM_SETEDITSTYLE, isRTL ? SES_BIDI : 0, SES_BIDI);
+    ::SendMessage((HWND)GetHWND(), EM_SETEDITSTYLE, lang.IsRTL() ? SES_BIDI : 0, SES_BIDI);
 
     UpdateRTLStyle();
 #endif
 }
 
+
+void AnyTranslatableTextCtrl::SetPlainText(const wxString& s)
+{
+    SetValue(EscapePlainText(s));
+}
+
+wxString AnyTranslatableTextCtrl::GetPlainText() const
+{
+    return UnescapePlainText(bidi::strip_pointless_control_chars(GetValue(), m_language.Direction()));
+}
+
+
 wxString AnyTranslatableTextCtrl::EscapePlainText(const wxString& s)
 {
     // Note: the escapes used here should match with
@@ -521,6 +563,9 @@ wxString AnyTranslatableTextCtrl::EscapePlainText(const wxString& s)
             case '\t':
                 s2 += "\\t";
                 break;
+            case '\a':
+                s2 += "\\a";
+                break;
             case '\0':
                 s2 += "\\0";
                 break;
@@ -574,6 +619,9 @@ wxString AnyTranslatableTextCtrl::UnescapePlainText(const wxString& s)
                 case 't':
                     s2 += '\t';
                     break;
+                case 'a':
+                    s2 += '\a';
+                    break;
                 case '0':
                     s2 += '\0';
                     break;
@@ -634,7 +682,7 @@ void AnyTranslatableTextCtrl::UpdateRTLStyle()
     ::ZeroMemory(&pf, sizeof(pf));
     pf.cbSize = sizeof(pf);
     pf.dwMask |= PFM_RTLPARA;
-    if (m_isRTL)
+    if (m_language.IsRTL())
         pf.wEffects |= PFE_RTLPARA;
 
     long start, end;
@@ -698,7 +746,7 @@ void AnyTranslatableTextCtrl::HighlightText()
 SourceTextCtrl::SourceTextCtrl(wxWindow *parent, wxWindowID winid)
     : AnyTranslatableTextCtrl(parent, winid, wxTE_READONLY)
 {
-    SetLanguageRTL(false); // English is LTR
+    SetLanguage(Language::English());
 }
 
 
@@ -762,6 +810,11 @@ void TranslationTextCtrl::DoSetValue(const wxString& value, int flags)
 void TranslationTextCtrl::SetPlainTextUserWritten(const wxString& value)
 {
     UndoGroup undo(this);
+
+#ifdef __WXOSX__
+    DisableAutomaticSubstitutions disableAuto(this);
+#endif
+
     SelectAll();
     WriteText(EscapePlainText(value));
     SetInsertionPointEnd();
